Module capability

Module capability 

Capability-based security system for Glyph runtime

Structs

CapabilitySet
A set of capabilities granted to a piece of code

Enums

Capability
Represents a capability that can be granted to code